==> gemrb-0.3.0.tar.gz: gemrb-0.3.0/gemrb/plugins/Core/MapMgr.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: MapMgr.h 4503 2007-02-27 16:43:46Z wjpalenstijn $
 *
 */

/**
 * @file MapMgr.h
 * Declares MapMgr class, loader for Map objects
 * @author The GemRB Project
 */

#ifndef MAPMGR_H
#define MAPMGR_H

#include "Plugin.h"
#include "DataStream.h"
#include "ActorBlock.h"
#include "Map.h"

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

/**
 * @class MapMgr
 * Abstract loader for Map objects
 */

class GEM_EXPORT MapMgr : public Plugin {
public:
	MapMgr(void);
	virtual ~MapMgr(void);
	virtual bool Open(DataStream* stream, bool autoFree = true) = 0;
	virtual Map* GetMap(const char* ResRef) = 0;

	virtual int GetStoredFileSize(Map *map) = 0;
	virtual int PutArea(DataStream* stream, Map *map) = 0;
	/** this function frees some memory common for all MapMgr */
	virtual void ReleaseMemory() = 0;
};

#endif

==> gemrb-0.3.2.tar.gz: gemrb-0.3.2/gemrb/plugins/Core/MapMgr.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: MapMgr.h 5497 2008-12-06 10:57:59Z avenger_teambg $
 *
 */

/**
 * @file MapMgr.h
 * Declares MapMgr class, loader for Map objects
 * @author The GemRB Project
 */

#ifndef MAPMGR_H
#define MAPMGR_H

#include "Plugin.h"
#include "DataStream.h"
#include "ActorBlock.h"
#include "Map.h"

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

/**
 * @class MapMgr
 * Abstract loader for Map objects
 */

class GEM_EXPORT MapMgr : public Plugin {
public:
	MapMgr(void);
	virtual ~MapMgr(void);
	virtual bool Open(DataStream* stream, bool autoFree = true) = 0;
	virtual bool ChangeMap(Map *map, bool day_or_night) = 0;
	virtual Map* GetMap(const char* ResRef, bool day_or_night) = 0;

	virtual int GetStoredFileSize(Map *map) = 0;
	virtual int PutArea(DataStream* stream, Map *map) = 0;
	/** this function frees some memory common for all MapMgr */
	virtual void ReleaseMemory() = 0;
};

#endif
